@@ -17,45 +17,53 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::OptionalSession::MSSQL
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Microsoft SQL Server Interesting Data Finder',
-      'Description'    => %q{
-        This module will search the specified MSSQL server for
-        'interesting' columns and data.
+    super(
+      update_info(
+        info,
+        'Name' => 'Microsoft SQL Server Interesting Data Finder',
+        'Description' => %q{
+          This module will search the specified MSSQL server for
+          'interesting' columns and data.
 
-        This module has been tested against the latest SQL Server 2019 docker container image (22/04/2021).
-      },
-      'Author'         => [ 'Robin Wood <robin[at]digininja.org>' ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+          This module has been tested against the latest SQL Server 2019 docker container image (22/04/2021).
+        },
+        'Author' => [ 'Robin Wood <robin[at]digininja.org>' ],
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'URL', 'http://www.digininja.org/metasploit/mssql_idf.php' ],
-        ]
-    ))
+        ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [IOC_IN_LOGS],
+          'Reliability' => []
+        }
+      )
+    )
 
     register_options(
       [
-        OptString.new('NAMES', [ true, 'Pipe separated list of column names',  'passw|bank|credit|card']),
-      ])
+        OptString.new('NAMES', [ true, 'Pipe separated list of column names', 'passw|bank|credit|card']),
+      ]
+    )
   end
 
   def print_with_underline(str)
     print_line(str)
-    print_line("=" * str.length)
+    print_line('=' * str.length)
   end
 
   def run
     headings = [
-      ["Database", "Schema", "Table", "Column", "Data Type", "Row Count"]
+      ['Database', 'Schema', 'Table', 'Column', 'Data Type', 'Row Count']
     ]
 
-    sql = ""
-    sql += "DECLARE @dbname nvarchar(255), @id int, @sql varchar (4000); "
-    sql += "DECLARE table_cursor CURSOR FOR SELECT name FROM sys.databases "
-    sql += "OPEN table_cursor "
-    sql += "FETCH NEXT FROM table_cursor INTO @dbname "
-    sql += "WHILE (@@FETCH_STATUS = 0) "
-    sql += "BEGIN "
+    sql = ''
+    sql += 'DECLARE @dbname nvarchar(255), @id int, @sql varchar (4000); '
+    sql += 'DECLARE table_cursor CURSOR FOR SELECT name FROM sys.databases '
+    sql += 'OPEN table_cursor '
+    sql += 'FETCH NEXT FROM table_cursor INTO @dbname '
+    sql += 'WHILE (@@FETCH_STATUS = 0) '
+    sql += 'BEGIN '
     sql += "SET @sql = 'select ';"
     sql += "SET @sql = @sql + ' ''' + @dbname + ''' as ''Database'', ';"
     sql += "SET @sql = @sql + 'sys.schemas.name as ''Schema'', ';"
@@ -69,9 +77,9 @@ class MetasploitModule < Msf::Auxiliary
 
     list = datastore['Names']
     where = "SET @sql = @sql + ' WHERE ("
-    list.split(/\|/).each { |val|
+    list.split(/\|/).each do |val|
       where += " lower(sys.columns.name) like ''%" + val + "%'' OR "
-    }
+    end
 
     where.slice!(-3, 4)
 
@@ -80,11 +88,11 @@ class MetasploitModule < Msf::Auxiliary
     sql += where
 
     sql += "SET @sql = @sql + 'and sys.objects.type=''U'';';"
-    sql += "EXEC (@sql);"
-    sql += "FETCH NEXT FROM table_cursor INTO @dbname "
-    sql += "END "
-    sql += "CLOSE table_cursor "
-    sql += "DEALLOCATE table_cursor "
+    sql += 'EXEC (@sql);'
+    sql += 'FETCH NEXT FROM table_cursor INTO @dbname '
+    sql += 'END '
+    sql += 'CLOSE table_cursor '
+    sql += 'DEALLOCATE table_cursor '
 
     begin
       if session
@@ -116,45 +124,45 @@ class MetasploitModule < Msf::Auxiliary
       return
     end
 
-    (column_data|headings).each { |row|
-      0.upto(4) { |col|
+    (column_data | headings).each do |row|
+      0.upto(4) do |col|
         widths[col] = row[col].length if row[col].length > widths[col]
-      }
-    }
+      end
+    end
 
-    widths.each { |a|
+    widths.each do |a|
       total_width += a
-    }
+    end
 
     print_line
 
-    buffer = ""
-    headings.each { |row|
-      0.upto(5) { |col|
+    buffer = ''
+    headings.each do |row|
+      0.upto(5) do |col|
         buffer += row[col].ljust(widths[col] + 1)
-      }
+      end
       print_line(buffer)
       print_line
-      buffer = ""
+      buffer = ''
 
-      0.upto(5) { |col|
-        buffer += print "=" * widths[col] + " "
-      }
+      0.upto(5) do |col|
+        buffer += print '=' * widths[col] + ' '
+      end
       print_line(buffer)
       print_line
-    }
+    end
 
-    column_data.each { |row|
-      count_sql = "SELECT COUNT(*) AS count FROM "
+    column_data.each do |row|
+      count_sql = 'SELECT COUNT(*) AS count FROM '
 
-      full_table = ""
-      column_name = ""
-      buffer = ""
-      0.upto(4) { |col|
+      full_table = ''
+      column_name = ''
+      buffer = ''
+      0.upto(4) do |col|
         full_table += row[col] + '.' if col < 3
         column_name = row[col] if col == 3
         buffer += row[col].ljust(widths[col] + 1)
-      }
+      end
       full_table.slice!(-1, 1)
       count_sql += full_table
 
@@ -166,7 +174,7 @@ class MetasploitModule < Msf::Auxiliary
       buffer += row_count.to_s
       print_line(buffer)
       print_line
-    }
+    end
 
     print_line
     disconnect
